==> fuioupay-sdk-1.0.0.20231012-20230926.115319-1-sources.jar: com/fshows/fuiou/request/trade/order/FuiouHisOrderQueryRequest.java <==
/**
 * fshows.com
 * Copyright (C) 2013-2022 All Rights Reserved.
 */
package com.fshows.fuiou.request.trade.order;

import com.fshows.fuiou.enums.FuiouApiDefinitionEnum;
import com.fshows.fuiou.request.base.FuiouBizRequest;
import com.fshows.fuiou.response.trade.order.FuiouOrderQueryResponse;
import lombok.Data;
import org.hibernate.validator.constraints.Length;

import javax.validation.constraints.NotBlank;
import java.io.Serializable;

/**
 *
 *
 * @author
 * @version FuiouHisOrderQueryRequest.java, v 0.1 2023-09-20 14:50:02
 */
@Data
public class FuiouHisOrderQueryRequest extends FuiouBizRequest<FuiouOrderQueryResponse, FuiouApiDefinitionEnum> implements Serializable {

    private static final long serialVersionUID = 6635937432099151799L;
    /**
     * 商户号,富友分配给二级商户的商户号
     *
     * (必填)
     */
    @NotBlank
    @Length(max = 15, message = "mchntCd长度不能超过15")
    private String mchntCd;

    /**
     * 终端号(没有真实终端号统一填88888888)
     *
     * (必填)
     */
    @NotBlank
    @Length(max = 8, message = "termId长度不能超过8")
    private String termId;

    /**
     * 订单类型: ALIPAY(统一下单、条码支付、服务窗支付) WECHAT(统一下单、条码支付、公众号支付、小程序) UNIONPAY BESTPAY(翼支付) PY68(银联分期-商户贴息) PY69(银联分期-持卡人贴息)
     *
     * (必填)
     */
    @NotBlank
    @Length(max = 20, message = "orderType长度不能超过20")
    private String orderType;

    /**
     * 商户订单号, 商户系统内部的订单号 (5到30个字符、只能包含字母数字,区分大小写)
     *
     * (必填)
     */
    @NotBlank
    @Length(max = 30, message = "mchntOrderNo长度不能超过30")
    private String mchntOrderNo;

    /**
     * 交易日期，非必填，默认当天。（格式yyyyMMdd）
     * 查询往日交易时，必填，支持查询90天内交易
     *
     * (非必填)
     */
    private String tradeDt;
}

==> fuioupay-sdk-1.0.0.20231205-sources.jar: com/fshows/fuiou/request/trade/order/FuiouHisOrderQueryRequest.java <==
/**
 * fshows.com
 * Copyright (C) 2013-2022 All Rights Reserved.
 */
package com.fshows.fuiou.request.trade.order;

import com.fshows.fuiou.enums.FuiouApiDefinitionEnum;
import com.fshows.fuiou.request.base.FuiouBizRequest;
import com.fshows.fuiou.response.trade.order.FuiouOrderQueryResponse;
import lombok.Data;
import org.hibernate.validator.constraints.Length;

import javax.validation.constraints.NotBlank;
import java.io.Serializable;

/**
 *
 *
 * @author
 * @version FuiouHisOrderQueryRequest.java, v 0.1 2023-09-20 14:50:02
 */
@Data
public class FuiouHisOrderQueryRequest extends FuiouBizRequest<FuiouOrderQueryResponse, FuiouApiDefinitionEnum> implements Serializable {

    private static final long serialVersionUID = 6635937432099151799L;
    /**
     * 商户号,富友分配给二级商户的商户号
     *
     * (必填)
     */
    @NotBlank
    @Length(max = 15, message = "mchntCd长度不能超过15")
    private String mchntCd;

    /**
     * 终端号(没有真实终端号统一填88888888)
     *
     * (必填)
     */
    @NotBlank
    @Length(max = 8, message = "termId长度不能超过8")
    private String termId;

    /**
     * 订单类型: ALIPAY(统一下单、条码支付、服务窗支付) WECHAT(统一下单、条码支付、公众号支付、小程序) UNIONPAY BESTPAY(翼支付) PY68(银联分期-商户贴息) PY69(银联分期-持卡人贴息)
     *
     * (必填)
     */
    @NotBlank
    @Length(max = 20, message = "orderType长度不能超过20")
    private String orderType;

    /**
     * 交易日期，非必填，默认当天。（格式yyyyMMdd）
     * 查询往日交易时，必填，支持查询90天内交易
     *
     * (非必填)
     */
    private String tradeDt;

    /**
     * 商户订单号, 商户系统内部的订单号 (5到30个字符、只能包含字母数字,区分大小写)
     *
     * (必填)
     */
    @NotBlank
    @Length(max = 30, message = "mchntOrderNo长度不能超过30")
    private String mchntOrderNo;

    /**
     * 条码流水(线下支付，条码流水号)
     *
     * (选填)
     */
    @Length(max = 32, message = "channelOrderId长度不能超过30")
    private String channelOrderId;

    /**
     * 渠道订单号(微信、支付宝流水号)
     *
     * (选填)
     */
    @Length(max = 32, message = "transactionId长度不能超过30")
    private String transactionId;
}
